@@ -31,7 +31,7 @@ class ReqClient:
         return self
 
     def __exit__(self, exc_type, exc_value, exc_traceback):
-        self.base_client.ws.close()
+        self.disconnect()
 
     def __repr__(self):
         return type(
@@ -43,6 +43,9 @@ class ReqClient:
     def __str__(self):
         return type(self).__name__
 
+    def disconnect(self):
+        self.base_client.ws.close()
+
     def send(self, param, data=None, raw=False):
         try:
             response = self.base_client.req(param, data)
@@ -135,39 +138,39 @@ class ReqClient:
 
     get_hotkey_list = get_hot_key_list
 
-    def trigger_hot_key_by_name(self, hotkeyName):
+    def trigger_hot_key_by_name(self, hotkeyName, contextName=None):
         """
         Triggers a hotkey using its name. For hotkey names
         See GetHotkeyList
 
         :param hotkeyName: Name of the hotkey to trigger
         :type hotkeyName: str
+        :param contextName: Name of context of the hotkey to trigger
+        :type contextName: str, optional
 
 
         """
-        payload = {"hotkeyName": hotkeyName}
+        payload = {"hotkeyName": hotkeyName, "contextName": contextName}
         self.send("TriggerHotkeyByName", payload)
 
     trigger_hotkey_by_name = trigger_hot_key_by_name
 
     def trigger_hot_key_by_key_sequence(
-        self, keyId, pressShift, pressCtrl, pressAlt, pressCmd
+        self, keyId, pressShift=None, pressCtrl=None, pressAlt=None, pressCmd=None
     ):
         """
         Triggers a hotkey using a sequence of keys.
 
         :param keyId: The OBS key ID to use. See https://github.com/obsproject/obs-studio/blob/master/libobs/obs-hotkeys.h
         :type keyId: str
-        :param keyModifiers: Object containing key modifiers to apply.
-        :type keyModifiers: dict
-        :param keyModifiers.shift: Press Shift
-        :type keyModifiers.shift: bool
-        :param keyModifiers.control: Press CTRL
-        :type keyModifiers.control: bool
-        :param keyModifiers.alt: Press ALT
-        :type keyModifiers.alt: bool
-        :param keyModifiers.cmd: Press CMD (Mac)
-        :type keyModifiers.cmd: bool
+        :param pressShift: Press Shift
+        :type pressShift: bool, optional
+        :param pressCtrl: Press CTRL
+        :type pressCtrl: bool, optional
+        :param pressAlt: Press ALT
+        :type pressAlt: bool, optional
+        :param pressCmd: Press CMD (Mac)
+        :type pressCmd: bool, optional
 
 
         """
@@ -435,7 +438,7 @@ class ReqClient:
 
     def set_record_directory(self, recordDirectory):
         """
-        Sets the current directory that the record output writes files to. 
+        Sets the current directory that the record output writes files to.
         IMPORTANT NOTE: Requires obs websocket v5.3 or higher.
 
         :param recordDirectory: Output directory
@@ -445,7 +448,7 @@ class ReqClient:
             "recordDirectory": recordDirectory,
         }
         return self.send("SetRecordDirectory", payload)
-    
+
     def get_source_active(self, name):
         """
         Gets the active and show state of a source
@@ -1781,7 +1784,7 @@ class ReqClient:
 
 
         """
-        self.send("ToggleRecord")
+        return self.send("ToggleRecord")
 
     def start_record(self):
         """
